# Generated by Django 2.0a1 on 2017-09-23 14:27

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('front', '0002_auto_20150123_0219'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='placeholderhistory',
            options={'ordering': ('-saved',)},
        ),
    ]
