<!doctype html>{% load i18n front_tags %}
<html lang="en">
  <head></head>
<body>
    {% front_edit "global" LANGUAGE_CODE %}aaa{% end_front_edit  %}
    {% front_edit_scripts editor="ace" %}
</body>
</html>
